@@ -1,7 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2004 Martyn Russell <ginxd@btopenworld.com>
- * Copyright (C) 2004 Imendio AB
+ * Copyright (C) 2004-2006 Imendio AB
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -20,32 +19,43 @@
  */
 
 #include <config.h>
+
 #include <string.h>
+#include <unistd.h>
+
+#include <gtk/gtk.h> 
 #include <glade/glade.h>
-#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <libgnomeui/gnome-href.h>
+#include <libgnomeui/libgnomeui.h>  
+#include <libgnomevfs/gnome-vfs-mime-utils.h>
 #include <loudmouth/loudmouth.h>
-#include <unistd.h>
 
 #include <libgossip/gossip-session.h>
 #include <libgossip/gossip-protocol.h>
 #include <libgossip/gossip-vcard.h>
+#include <libgossip/gossip-utils.h>
 
 #include "gossip-account-chooser.h"
 #include "gossip-app.h"
 #include "gossip-vcard-dialog.h"
+#include "gossip-image-chooser.h"
+#include "gossip-preferences.h"
 
-#define DEBUG_MSG(x)  
+#define DEBUG_MSG(x)
 /* #define DEBUG_MSG(args) g_printerr args ; g_printerr ("\n");  */
 
 #define STRING_EMPTY(x) ((x) == NULL || (x)[0] == '\0')
 
-#define VCARD_TIMEOUT 20000
-#define SAVED_TIMEOUT 10000
+#define VCARD_TIMEOUT     20000
+#define SAVED_TIMEOUT     10000
 
+#define RESPONSE_SAVE     1
 
-struct _GossipVCardDialog {
+#define AVATAR_MAX_HEIGHT 96
+#define AVATAR_MAX_WIDTH  96
+
+typedef struct {
 	GtkWidget *dialog;
 
 	GtkWidget *hbox_account;
@@ -67,67 +77,216 @@ struct _GossipVCardDialog {
 
 	GtkWidget *textview_description;
 
-	GtkWidget *vbox_waiting;
-	GtkWidget *progressbar_waiting;
-
-	GtkWidget *hbox_saved;
-
 	GtkWidget *button_cancel;
-	GtkWidget *button_ok;
+	GtkWidget *button_save;
+	
+	GtkWidget *button_image;
+	GtkWidget *avatar_chooser;
 
-	guint      wait_id;
-	guint      pulse_id;
 	guint      timeout_id; 
 	guint      saved_id;
 
 	gboolean   requesting_vcard;
 
 	gint       last_account_selected;
-};
 
+	GnomeThumbnailFactory *thumbs;
+} GossipVCardDialog;
 
-typedef struct _GossipVCardDialog GossipVCardDialog;
+static void     vcard_dialog_avatar_chooser_response_cb (GtkWidget         *widget,
+							 gint               response,
+							 GossipVCardDialog *dialog);
+static void     vcard_dialog_avatar_clicked_cb          (GtkWidget         *button,
+							 GossipVCardDialog *dialog);
+static void     vcard_dialog_avatar_update_preview_cb   (GtkFileChooser    *chooser,
+							 GossipVCardDialog *dialog);
+static void     vcard_dialog_set_account_to_last        (GossipVCardDialog *dialog);
+static void     vcard_dialog_lookup_start               (GossipVCardDialog *dialog);
+static void     vcard_dialog_lookup_stop                (GossipVCardDialog *dialog);
+static void     vcard_dialog_get_vcard_cb               (GossipResult       result,
+							 GossipVCard       *vcard,
+							 GossipVCardDialog *dialog);
+static void     vcard_dialog_set_vcard                  (GossipVCardDialog *dialog);
+static void     vcard_dialog_set_vcard_cb               (GossipResult       result,
+							 GossipVCardDialog *dialog);
+static gboolean vcard_dialog_timeout_cb                 (GossipVCardDialog *dialog);
+static void     vcard_dialog_account_changed_cb         (GtkWidget         *combo_box,
+							 GossipVCardDialog *dialog);
+static void     vcard_dialog_response_cb                (GtkDialog         *widget,
+							 gint               response,
+							 GossipVCardDialog *dialog);
+static void     vcard_dialog_destroy_cb                 (GtkWidget         *widget,
+							 GossipVCardDialog *dialog);
 
+/* Called from Glade, so it shouldn't be static. */
+GtkWidget *vcard_dialog_create_avatar_chooser (gpointer data);
 
-enum {
-	COL_ACCOUNT_IMAGE,
-	COL_ACCOUNT_TEXT,
-	COL_ACCOUNT_CONNECTED,
-	COL_ACCOUNT_POINTER,
-	COL_ACCOUNT_COUNT
-};
-
-
-static gint     vcard_dialog_get_account_count   (GossipVCardDialog *dialog);
-static void     vcard_dialog_set_account_to_last (GossipVCardDialog *dialog);
-static void     vcard_dialog_lookup_start        (GossipVCardDialog *dialog);
-static void     vcard_dialog_lookup_stop         (GossipVCardDialog *dialog);
-static void     vcard_dialog_get_vcard_cb        (GossipResult       result,
-						  GossipVCard       *vcard,
-						  GossipVCardDialog *dialog);
-static void     vcard_dialog_set_vcard           (GossipVCardDialog *dialog);
-static void     vcard_dialog_set_vcard_cb        (GossipResult       result,
-						  GossipVCardDialog *dialog);
-static gboolean vcard_dialog_progress_pulse_cb   (GtkWidget         *progressbar);
-static gboolean vcard_dialog_wait_cb             (GossipVCardDialog *dialog);
-static gboolean vcard_dialog_timeout_cb          (GossipVCardDialog *dialog);
-static gboolean vcard_dialog_saved_cb            (GtkWidget         *widget);
-static void     vcard_dialog_account_changed_cb  (GtkWidget         *combo_box,
-						  GossipVCardDialog *dialog);
-static void     vcard_dialog_response_cb         (GtkDialog         *widget,
-						  gint               response,
-						  GossipVCardDialog *dialog);
-static void     vcard_dialog_destroy_cb          (GtkWidget         *widget,
-						  GossipVCardDialog *dialog);
-
-
-static gint
-vcard_dialog_get_account_count (GossipVCardDialog *dialog) 
+GtkWidget *
+vcard_dialog_create_avatar_chooser (gpointer data)
 {
-	GtkTreeModel *model;
+	GtkWidget *chooser;
+
+	chooser = gossip_image_chooser_new ();
+
+	gossip_image_chooser_set_image_max_size (GOSSIP_IMAGE_CHOOSER (chooser),
+						 AVATAR_MAX_WIDTH, 
+						 AVATAR_MAX_HEIGHT);
+
+	gtk_widget_show_all (chooser);
+
+	gtk_widget_set_size_request (chooser, 
+				     AVATAR_MAX_WIDTH / 2,
+				     AVATAR_MAX_HEIGHT / 2);
+
+	return chooser;
+}
+
+static void
+vcard_dialog_avatar_chooser_response_cb (GtkWidget         *widget,
+					 gint               response,
+					 GossipVCardDialog *dialog)
+{
+	if (response == GTK_RESPONSE_OK) {
+		gchar *filename;
+		gchar *path;
+
+		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (widget));
+		gossip_image_chooser_set_from_file (GOSSIP_IMAGE_CHOOSER (dialog->avatar_chooser),
+						    filename);
+		g_free (filename);
+
+		path = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (widget));
+		if (path) {
+			gconf_client_set_string (gossip_app_get_gconf_client (),
+						 GCONF_UI_AVATAR_DIRECTORY,
+						 path,
+						 NULL);
+			g_free (path);
+		}
+	} else if (response == GTK_RESPONSE_NO) {
+		gossip_image_chooser_set_image_data (GOSSIP_IMAGE_CHOOSER (dialog->avatar_chooser),
+						     NULL, 0);
+	}
+
+	gtk_widget_destroy (widget);
+}
+
+static void
+vcard_dialog_avatar_clicked_cb (GtkWidget         *button,
+				GossipVCardDialog *dialog) 
+{
+	GtkWidget *chooser_dialog;
+	gchar     *path;
+	GtkWidget *avatar_chooser;
+	GtkWidget *image;
+	
+	avatar_chooser = dialog->avatar_chooser;
+
+	chooser_dialog = gtk_file_chooser_dialog_new (_("Select Your Avatar Image"),
+						      GTK_WINDOW (dialog->dialog),
+						      GTK_FILE_CHOOSER_ACTION_OPEN,
+						      _("No Image"),
+						      GTK_RESPONSE_NO,
+						      GTK_STOCK_CANCEL,
+						      GTK_RESPONSE_CANCEL,
+						      GTK_STOCK_OPEN,
+						      GTK_RESPONSE_OK,
+						      NULL);
+
+	gtk_window_set_transient_for (GTK_WINDOW (chooser_dialog), 
+				      GTK_WINDOW (dialog->dialog));
+
+ 	gtk_dialog_set_default_response (GTK_DIALOG (chooser_dialog), GTK_RESPONSE_ACCEPT);
+
+	path = gconf_client_get_string (gossip_app_get_gconf_client (),
+					GCONF_UI_AVATAR_DIRECTORY,
+					NULL);
+
+ 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (chooser_dialog),
+					     path ? path : g_get_home_dir ());
+	g_free (path);
+
+	gtk_file_chooser_set_use_preview_label (GTK_FILE_CHOOSER (chooser_dialog), FALSE);
+	
+	image = gtk_image_new ();
+	gtk_file_chooser_set_preview_widget (GTK_FILE_CHOOSER (chooser_dialog), image);
+	gtk_widget_set_size_request (image, AVATAR_MAX_WIDTH, AVATAR_MAX_HEIGHT);
+	gtk_widget_show (image);
+
+	g_signal_connect (chooser_dialog, "update-preview",
+			  G_CALLBACK (vcard_dialog_avatar_update_preview_cb), 
+			  dialog);
+
+	g_signal_connect (chooser_dialog, "response",
+			  G_CALLBACK (vcard_dialog_avatar_chooser_response_cb),
+			  dialog);
+
+	gtk_widget_show (chooser_dialog);
+}
+
+static GdkPixbuf *
+vcard_dialog_scale_down_to_width (GdkPixbuf *pixbuf, gint wanted_width)
+{
+	gint      width, height;
+	gdouble   factor;
+
+	width = gdk_pixbuf_get_width (pixbuf);
+	height = gdk_pixbuf_get_height (pixbuf);
+
+	if (width > wanted_width) {
+		factor = (gdouble) wanted_width / MAX (width, height);
 		
-	model = gtk_combo_box_get_model (GTK_COMBO_BOX (dialog->account_chooser));
-        return gtk_tree_model_iter_n_children  (model, NULL);
+		width = width * factor;
+		height = height * factor;
+
+		return gdk_pixbuf_scale_simple (pixbuf,
+						width, height,
+						GDK_INTERP_BILINEAR);
+	}
+
+	return g_object_ref (pixbuf);
+}
+
+static void 
+vcard_dialog_avatar_update_preview_cb (GtkFileChooser    *chooser,
+				       GossipVCardDialog *dialog) 
+{
+	gchar *uri;
+
+	uri = gtk_file_chooser_get_preview_uri (chooser);
+	
+	if (uri) {
+		GtkWidget *image;
+		GdkPixbuf *pixbuf;
+		GdkPixbuf *scaled_pixbuf;
+		gchar     *mime_type;
+
+		if (!dialog->thumbs) {
+			dialog->thumbs = gnome_thumbnail_factory_new (GNOME_THUMBNAIL_SIZE_NORMAL);
+		}
+		
+		mime_type = gnome_vfs_get_mime_type (uri);
+		pixbuf = gnome_thumbnail_factory_generate_thumbnail (dialog->thumbs,
+								     uri,
+								     mime_type);
+		image = gtk_file_chooser_get_preview_widget (chooser);
+
+		if (pixbuf) {
+			scaled_pixbuf = vcard_dialog_scale_down_to_width (
+				pixbuf, AVATAR_MAX_WIDTH);
+			gtk_image_set_from_pixbuf (GTK_IMAGE (image), scaled_pixbuf);
+			g_object_unref (scaled_pixbuf);
+			g_object_unref (pixbuf);
+		} else {
+			gtk_image_set_from_stock (GTK_IMAGE (image),
+						  "gtk-dialog-question",
+						  GTK_ICON_SIZE_DIALOG);
+		}
+
+		g_free (mime_type);
+	}
+
+	gtk_file_chooser_set_preview_widget_active (chooser, TRUE);
 }
 
 static void
@@ -152,26 +311,18 @@ vcard_dialog_lookup_start (GossipVCardDialog *dialog)
 	GossipAccount        *account;
 	GossipAccountChooser *account_chooser;
 
-	/* update widgets */
 	gtk_widget_set_sensitive (dialog->table_vcard, FALSE);
 	gtk_widget_set_sensitive (dialog->account_chooser, FALSE);
-	gtk_widget_set_sensitive (dialog->button_ok, FALSE);
-
-	/* set up timers */
-	dialog->wait_id = g_timeout_add (2000, 
-					 (GSourceFunc)vcard_dialog_wait_cb,
-					 dialog);
+	gtk_widget_set_sensitive (dialog->button_save, FALSE);
 
 	dialog->timeout_id = g_timeout_add (VCARD_TIMEOUT, 
 					    (GSourceFunc)vcard_dialog_timeout_cb,
 					    dialog);
 
-	/* get selected and look it up */
 	session = gossip_app_get_session ();
 	account_chooser = GOSSIP_ACCOUNT_CHOOSER (dialog->account_chooser);
 	account = gossip_account_chooser_get_account (account_chooser);
 
-	/* request current vCard */
 	gossip_session_get_vcard (session,
 				  account,
 				  NULL,
@@ -189,23 +340,9 @@ vcard_dialog_lookup_stop (GossipVCardDialog *dialog)
 {
 	dialog->requesting_vcard = FALSE;
 
-	/* update widgets */
 	gtk_widget_set_sensitive (dialog->table_vcard, TRUE);
 	gtk_widget_set_sensitive (dialog->account_chooser, TRUE);
-	gtk_widget_set_sensitive (dialog->button_ok, TRUE);
-
-	gtk_widget_hide (dialog->vbox_waiting); 
-
-	/* clean up timers */
-	if (dialog->wait_id != 0) {
-		g_source_remove (dialog->wait_id);
-		dialog->wait_id = 0;
-	}
-
-	if (dialog->pulse_id != 0) {
-		g_source_remove (dialog->pulse_id);
-		dialog->pulse_id = 0;
-	}
+	gtk_widget_set_sensitive (dialog->button_save, TRUE);
 
 	if (dialog->timeout_id != 0) {
 		g_source_remove (dialog->timeout_id);
@@ -226,6 +363,8 @@ vcard_dialog_get_vcard_cb (GossipResult       result,
 	GtkComboBox   *combo_box;
 	GtkTextBuffer *buffer;
 	const gchar   *str;
+	const guchar  *avatar;
+	gsize          avatar_size;
 
 	DEBUG_MSG (("VCardDialog: Got a VCard response"));
 
@@ -252,7 +391,11 @@ vcard_dialog_get_vcard_cb (GossipResult       result,
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (dialog->textview_description));
 	gtk_text_buffer_set_text (buffer, STRING_EMPTY (str) ? "" : str, -1);
 
-	/* save position incase the next lookup fails */
+	avatar = gossip_vcard_get_avatar (vcard, &avatar_size);
+	gossip_image_chooser_set_image_data (GOSSIP_IMAGE_CHOOSER (dialog->avatar_chooser),
+					     (gchar*) avatar, avatar_size);
+
+	/* Save position incase the next lookup fails. */
 	combo_box = GTK_COMBO_BOX (dialog->account_chooser);
 	dialog->last_account_selected = gtk_combo_box_get_active (combo_box);
 }
@@ -263,11 +406,15 @@ vcard_dialog_set_vcard (GossipVCardDialog *dialog)
 	GossipVCard          *vcard;
 	GossipAccount        *account;
 	GossipAccountChooser *account_chooser;
+	GossipProtocol       *protocol;
+	GossipContact        *contact;
 	GError               *error = NULL;
 	GtkTextBuffer        *buffer;
 	GtkTextIter           iter_begin, iter_end;
 	gchar                *description;
 	const gchar          *str;
+	gchar                *avatar;
+	gsize                 avatar_size;
 
 	if (!gossip_app_is_connected ()) {
 		DEBUG_MSG (("VCardDialog: Not connected, not setting VCard"));
@@ -294,6 +441,10 @@ vcard_dialog_set_vcard (GossipVCardDialog *dialog)
 	gossip_vcard_set_description (vcard, description);
 	g_free (description);
 
+	gossip_image_chooser_get_image_data (GOSSIP_IMAGE_CHOOSER (dialog->avatar_chooser),
+					     &avatar, &avatar_size);
+	gossip_vcard_set_avatar (vcard, avatar, avatar_size);
+
 	/* NOTE: if account is NULL, all accounts will get the same vcard */
 	account_chooser = GOSSIP_ACCOUNT_CHOOSER (dialog->account_chooser);
 	account = gossip_account_chooser_get_account (account_chooser);
@@ -304,6 +455,12 @@ vcard_dialog_set_vcard (GossipVCardDialog *dialog)
 				  (GossipResultCallback) vcard_dialog_set_vcard_cb,
 				  dialog, &error);
 
+	protocol = gossip_session_get_protocol (gossip_app_get_session (), account);
+	contact = gossip_protocol_get_own_contact (protocol);
+	gossip_contact_set_avatar (GOSSIP_CONTACT(contact), avatar, avatar_size);
+
+	g_free (avatar);
+
 	g_object_unref (account);
 }
 
@@ -312,40 +469,8 @@ vcard_dialog_set_vcard_cb (GossipResult       result,
 			   GossipVCardDialog *dialog)
 {
 	DEBUG_MSG (("VCardDialog: Got a VCard response"));
-  
-	/* if multiple accounts, wait for the close button */
-	if (vcard_dialog_get_account_count (dialog) <= 1) {
-		gtk_widget_destroy (dialog->dialog);
-		return;
-	}
-
-	/* inform the user */
-	gtk_widget_show (dialog->hbox_saved);
-
-	dialog->pulse_id = g_timeout_add (SAVED_TIMEOUT, 
-					  (GSourceFunc)vcard_dialog_saved_cb, 
-					  dialog->hbox_saved);
-}
-
-static gboolean 
-vcard_dialog_progress_pulse_cb (GtkWidget *progressbar)
-{
-	g_return_val_if_fail (progressbar != NULL, FALSE);
-	gtk_progress_bar_pulse (GTK_PROGRESS_BAR (progressbar));
-
-	return TRUE;
-}
-
-static gboolean
-vcard_dialog_wait_cb (GossipVCardDialog *dialog)
-{
-	gtk_widget_show (dialog->vbox_waiting);
-
-	dialog->pulse_id = g_timeout_add (50, 
-					  (GSourceFunc)vcard_dialog_progress_pulse_cb, 
-					  dialog->progressbar_waiting);
-
-	return FALSE;
+	
+	gtk_widget_destroy (dialog->dialog);
 }
 
 static gboolean
@@ -355,10 +480,10 @@ vcard_dialog_timeout_cb (GossipVCardDialog *dialog)
 
 	vcard_dialog_lookup_stop (dialog);
 
-	/* select last successfull account */
+	/* Select last successfull account */
 	vcard_dialog_set_account_to_last (dialog);
 
-	/* show message dialog and the account dialog */
+	/* Show message dialog and the account dialog */
 	md = gtk_message_dialog_new_with_markup (GTK_WINDOW (dialog->dialog),
 						 GTK_DIALOG_MODAL |
 						 GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -375,17 +500,9 @@ vcard_dialog_timeout_cb (GossipVCardDialog *dialog)
 	return FALSE;
 }
 
-static gboolean 
-vcard_dialog_saved_cb (GtkWidget *widget)
-{
-	gtk_widget_hide (widget);
-	
-	return FALSE;
-}
-
 static void
 vcard_dialog_account_changed_cb (GtkWidget         *combo_box,
-					 GossipVCardDialog *dialog)
+				 GossipVCardDialog *dialog)
 {
 	vcard_dialog_lookup_start (dialog);
 }
@@ -395,18 +512,23 @@ vcard_dialog_response_cb (GtkDialog         *widget,
 			  gint               response, 
 			  GossipVCardDialog *dialog)
 {
-	if (response == GTK_RESPONSE_OK) {
+	switch (response) {
+	case RESPONSE_SAVE:
 		vcard_dialog_set_vcard (dialog);
 		return;
-	}
 
-	if (response == GTK_RESPONSE_CANCEL && dialog->requesting_vcard) {
-		/* change widgets so they are unsensitive */
-		vcard_dialog_lookup_stop (dialog);
+	case GTK_RESPONSE_CANCEL:
+		if (dialog->requesting_vcard) {
+			/* Change widgets so they are unsensitive */
+			vcard_dialog_lookup_stop (dialog);
+			
+			/* Select last successfull account */
+			vcard_dialog_set_account_to_last (dialog);
+			return;
+		}
 
-		/* select last successfull account */
-		vcard_dialog_set_account_to_last (dialog);
-		return;
+	default:
+		break;
 	}
 
 	gtk_widget_destroy (dialog->dialog);
@@ -416,12 +538,8 @@ static void
 vcard_dialog_destroy_cb (GtkWidget         *widget, 
 			 GossipVCardDialog *dialog)
 {
-	GossipSession *session;
-
 	vcard_dialog_lookup_stop (dialog);
 
-	session = gossip_app_get_session ();
-
 	g_free (dialog);
 }
 
@@ -453,11 +571,10 @@ gossip_vcard_dialog_show (GtkWindow *parent)
 				       "entry_web_site", &dialog->entry_web_site,
 				       "entry_email", &dialog->entry_email,
 				       "textview_description", &dialog->textview_description,
-				       "vbox_waiting", &dialog->vbox_waiting,
-				       "progressbar_waiting", &dialog->progressbar_waiting,
-				       "hbox_saved", &dialog->hbox_saved,
 				       "button_cancel", &dialog->button_cancel,
-				       "button_ok", &dialog->button_ok,
+				       "button_save", &dialog->button_save,
+				       "button_image", &dialog->button_image,
+				       "avatar_chooser", &dialog->avatar_chooser,
 				       NULL);
 
 	gossip_glade_connect (glade, 
@@ -479,7 +596,12 @@ gossip_vcard_dialog_show (GtkWindow *parent)
 
 	g_object_unref (size_group);
 
-	/* sort out accounts */
+	/* Setup image chooser */
+	g_signal_connect (dialog->button_image, "clicked",
+			  G_CALLBACK (vcard_dialog_avatar_clicked_cb),
+			  dialog);
+	
+	/* Sort out accounts */
 	session = gossip_app_get_session ();
 
 	dialog->account_chooser = gossip_account_chooser_new (session);
@@ -493,25 +615,13 @@ gossip_vcard_dialog_show (GtkWindow *parent)
 
 	gtk_widget_show (dialog->account_chooser);
 
-	/* select first */
+	/* Select first */
 	accounts = gossip_session_get_accounts (session);
 	if (g_list_length (accounts) > 1) {
 		gtk_widget_show (dialog->hbox_account);
-
-		gtk_button_set_use_stock (GTK_BUTTON (dialog->button_cancel), TRUE);
-		gtk_button_set_label (GTK_BUTTON (dialog->button_cancel), "gtk-close");
-
-		gtk_button_set_use_stock (GTK_BUTTON (dialog->button_ok), TRUE);
-		gtk_button_set_label (GTK_BUTTON (dialog->button_ok), "gtk-apply");
 	} else {
-		/* show no accounts combo box */	
+		/* Show no accounts combo box */	
 		gtk_widget_hide (dialog->hbox_account);
-
-		gtk_button_set_use_stock (GTK_BUTTON (dialog->button_cancel), TRUE);
-		gtk_button_set_label (GTK_BUTTON (dialog->button_cancel), "gtk-cancel");
-
-		gtk_button_set_use_stock (GTK_BUTTON (dialog->button_ok), TRUE);
-		gtk_button_set_label (GTK_BUTTON (dialog->button_ok), "gtk-ok");
 	}
 
 	g_list_foreach (accounts, (GFunc)g_object_unref, NULL);
@@ -521,5 +631,8 @@ gossip_vcard_dialog_show (GtkWindow *parent)
 		gtk_window_set_transient_for (GTK_WINDOW (dialog->dialog), parent); 
 	}
 
+	gtk_widget_show (dialog->dialog);
+	
 	vcard_dialog_lookup_start (dialog);
 }
+
